@page {
    margin-top: 1cm;
    size: A4;

    @bottom-right {
        content: counter(page) " of " counter(pages);
    }

    @bottom-center {
        color: #808080;
        content: string(heading-name) " - " string(heading-title);
    }

    @top-right {
        background: url(kabisa-logo-two-color.svg) no-repeat bottom;
        background-size: 5cm;
        content: "";
        width: 5cm;
    }
}

@page cover {
    @bottom-center {
        content: "";
    }

    @bottom-right {
        content: "";
    }
}

html {
    font-family: system-ui;
    font-size: 15px;
    line-height: 1.5;
}

p.blocktext {
    margin-left: auto;
    margin-right: auto;
    overflow-wrap: break-word;
}

img {
    display: block;
    margin-left: auto;
    margin-right: auto
}
